==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/bibtexfileexporterxml.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXBIBTEXFILEEXPORTERXML_H
#define BIBTEXBIBTEXFILEEXPORTERXML_H

#include <bibtexelement.h>
#include <bibtexfileexporter.h>

namespace BibTeX
{
    class BibTeXEntry;
    class BibTeXString;
    class BibTeXComment;

    /**
    @author Thomas Fischer
    */
    class BibTeXFileExporterXML : public BibTeXFileExporter
    {
    public:
        BibTeXFileExporterXML();
        ~BibTeXFileExporterXML();

        bool save( QIODevice* iodevice, BibTeXFile* bibtexfile );
        bool save( QIODevice* iodevice, BibTeXElement* element );

    public slots:
        void cancel();

    private:
        bool cancelFlag;

        bool write( QTextStream&stream, BibTeXElement *element );
        bool writeEntry( QTextStream &stream, BibTeXEntry* entry );
        bool writeString( QTextStream &stream, BibTeXString *string );
        bool writeComment( QTextStream &stream, BibTeXComment *comment );

        QString itemToString( const BibTeXElement::FieldItems::iterator& begin, const BibTeXElement::FieldItems::iterator& end );
    };

}

#endif

==> kbibtex-0.1.4.tar.bz2: kbibtex-0.1.4/src/bibtexfileexporterxml.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXBIBTEXFILEEXPORTERXML_H
#define BIBTEXBIBTEXFILEEXPORTERXML_H

#include <bibtexelement.h>
#include <bibtexfileexporter.h>
#include <bibtexvalue.h>

namespace BibTeX
{
    class BibTeXEntry;
    class BibTeXString;
    class BibTeXComment;

    /**
    @author Thomas Fischer
    */
    class BibTeXFileExporterXML : public BibTeXFileExporter
    {
    public:
        BibTeXFileExporterXML();
        ~BibTeXFileExporterXML();

        bool save( QIODevice* iodevice, BibTeXFile* bibtexfile, QStringList *errorLog = NULL );
        bool save( QIODevice* iodevice, BibTeXElement* element, QStringList *errorLog = NULL );

    public slots:
        void cancel();

    private:
        bool cancelFlag;

        bool write( QTextStream&stream, BibTeXElement *element );
        bool writeEntry( QTextStream &stream, BibTeXEntry* entry );
        bool writeString( QTextStream &stream, BibTeXString *string );
        bool writeComment( QTextStream &stream, BibTeXComment *comment );

        QString valueToString( BibTeXValue *value );
    };

}

#endif
